@@ -1,10 +1,6 @@
 #ifndef ESS_SAMPLER_H
 #define ESS_SAMPLER_H
 
-//#ifdef _OPENMP
-//#include <omp.h>
-//#endif
-
 #ifndef CCODE
 #include <RcppArmadillo.h>
 using Rcpp::Rcout;
@@ -27,6 +23,7 @@ using Rcpp::Rcerr;
 #include "HRR_Chain.h"
 #include "SUR_Chain.h"
 
+
 template<typename T>  //  the template here should be a class derived from ESS_Atom
 class ESS_Sampler{
     
@@ -34,7 +31,7 @@ public:
     
     // Constructor - nChains and type of MCMC
     ESS_Sampler( Utils::SUR_Data& surData , unsigned int nChains_ , double temperatureRatio ,
-                Gamma_Sampler_Type gamma_sampler_type, Gamma_Type gamma_type, Beta_Type beta_type, Covariance_Type covariance_type, bool output_CPO , unsigned int burnin_ );
+                Gamma_Sampler_Type gamma_sampler_type, Gamma_Type gamma_type, Beta_Type beta_type, Covariance_Type covariance_type, bool output_CPO , int maxThreads , unsigned int burnin_ );
     
     ESS_Sampler( Utils::SUR_Data& surData , unsigned int nChains_ , double temperatureRatio ) :
     ESS_Sampler( surData , nChains_ , temperatureRatio ,
@@ -80,6 +77,7 @@ private:
     
     unsigned int nChains;
     unsigned int burnin;
+    int maxThreads;
     
     // Pointer to chains -
     // we use pointers so that the client can ask for the original object and manipulate them as he wish
@@ -98,7 +96,7 @@ private:
 
 template<typename T>
 ESS_Sampler<T>::ESS_Sampler( Utils::SUR_Data& surData , unsigned int nChains_ , double temperatureRatio ,
-                            Gamma_Sampler_Type gamma_sampler_type, Gamma_Type gamma_type, Beta_Type beta_type, Covariance_Type covariance_type, bool output_CPO , unsigned int burnin_ ):
+                            Gamma_Sampler_Type gamma_sampler_type, Gamma_Type gamma_type, Beta_Type beta_type, Covariance_Type covariance_type, bool output_CPO , int maxThreads, unsigned int burnin_ ):
 nChains(nChains_),
 burnin(burnin_),
 chain(std::vector<std::shared_ptr<T>>(nChains)),
@@ -114,7 +112,7 @@ global_count(0)
     
     for( unsigned int i=0; i<nChains; ++i )
         chain[i] = std::make_shared<T>( surData ,
-                                       gamma_sampler_type, gamma_type, beta_type, covariance_type, output_CPO,
+                                       gamma_sampler_type, gamma_type, beta_type, covariance_type, output_CPO, maxThreads ,
                                        std::pow( temperatureRatio , (double)i ) );  // default init for now
 }
 
@@ -143,6 +141,7 @@ void ESS_Sampler<T>::localStep()
 #ifdef _OPENMP
 #pragma omp parallel for schedule(static,1)
 #endif
+    
     for( unsigned int i=0; i<nChains; ++i )
         chain[i] -> step();
     
@@ -165,7 +164,7 @@ std::pair<unsigned int , unsigned int>  ESS_Sampler<T>::randomChainSelect()
     unsigned int chainIdx = 1, firstChain = 0, secondChain = 1;
     
     // Select the chains to swap
-    chainIdx = (nChains>2) ? Distributions::randIntUniform(1, (nChains)*(nChains-1)/2 ) : 1;   // (nChains-1)*(nChains-2)/2 is the number of possible chain combinations with nChains
+    chainIdx = (nChains>2) ? randIntUniform(1, (nChains)*(nChains-1)/2 ) : 1;   // (nChains-1)*(nChains-2)/2 is the number of possible chain combinations with nChains
     
     for(unsigned int c=1; c<nChains; ++c)
     {
@@ -190,8 +189,8 @@ std::pair<unsigned int , unsigned int>  ESS_Sampler<T>::nearChainSelect()
     
     if( nChains>2 )
     {
-        firstChain = Distributions::randIntUniform(1, nChains-2 );  // so not the first (0) or last (nChains-1) indexes
-        secondChain = ( Distributions::randU01() < 0.5 ) ? firstChain-1 : firstChain+1 ; // then select a neighbour
+        firstChain = randIntUniform(1, nChains-2 );  // so not the first (0) or last (nChains-1) indexes
+        secondChain = ( randU01() < 0.5 ) ? firstChain-1 : firstChain+1 ; // then select a neighbour
     }
     
     return std::pair<unsigned int , unsigned int>( firstChain , secondChain );
@@ -207,7 +206,7 @@ void ESS_Sampler<T>::globalStep()
     
     if( nChains > 1 )
     {
-        tmpRand = Distributions::randU01();
+        tmpRand = randU01();
         if( tmpRand < 0.9 )
         {
             if( tmpRand < 0.5 )
@@ -241,14 +240,21 @@ void ESS_Sampler<T>::updateTemperatures()
     
     if( getGlobalAccRate() > 0.3 )
     {
-        tempRatio *= 1.1 ;
+        // tempRatio *= 1.1 ;
+        tempRatio = std::min( 100., tempRatio * 1.1 ) ;
         
         for( unsigned int i=1; i < nChains ; ++i )
         {
             chain[i]->setTemperature( tempRatio * chain[i-1]->getTemperature() );
         }
         
-        Rcout << "Temperature ladder updated, new temperature ratio : " << tempRatio << std::endl;
+        Rcout << "Temperature ladder updated, new temperature ratio : " << tempRatio;// << std::endl;
+        
+        /*for( unsigned int i=2; i < nChains ; ++i )
+        {
+            Rcout << " -- ratio" << i << ": " << chain[i]->getTemperature();
+        }
+        Rcout  << std::endl;*/
         
     }else if( getGlobalAccRate() < 0.05 )
     {
@@ -259,9 +265,16 @@ void ESS_Sampler<T>::updateTemperatures()
             chain[i]->setTemperature( tempRatio * chain[i-1]->getTemperature() );
         }
         
-        Rcout << "Temperature ladder updated, new temperature ratio : " << tempRatio << std::endl;
+        Rcout << "Temperature ladder updated, new temperature ratio : " << tempRatio;// << std::endl;
+        
+        /*for( unsigned int i=2; i < nChains ; ++i )
+        {
+            Rcout << " ratio" << i << ": " << chain[i]->getTemperature();
+        }
+        Rcout  << std::endl;*/
     }
     
+    
     // I want to maintain a sort-of-moving avaerage acceptance count for the global moves, so that
     // when we check if we should update the temperatures we only check in the near-past
     // in order to do this, I simply reset the varaibles each time I update the temperature
@@ -294,10 +307,11 @@ int ESS_Sampler<T>::allExchangeAll_step()
     
     // Compute the swap probabilities
     pExchange(0) = 0.; // these are log probabilities, remember!
-    
+   
 #ifdef _OPENMP
 #pragma omp parallel for
 #endif
+    
     for(unsigned int tabIndex = 1; tabIndex <= nChainCombinations; ++tabIndex)
     {
         
@@ -316,7 +330,7 @@ int ESS_Sampler<T>::allExchangeAll_step()
     arma::vec cumulPExchange = arma::cumsum( arma::exp( pExchange - logSumWeights ) ); // this should sum to one
     
     // Now select which swap happens
-    double val = Distributions::randU01();
+    double val = randU01();
     
     unsigned int swapIdx = 0;
     while( val > cumulPExchange(swapIdx) )
